@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009 */
+/* Copyright (c) Philip Hazel, 2009, 2011 */
 
 /* This module contains functions for doing things to paragraphs. */
 
@@ -244,11 +244,6 @@ for (ii = i; ii != i->partner; ii = ii->next)
     {
     ii->p.txtblk->pin_flags = (ii->p.txtblk->pin_flags &
       (PIN_FIXED|PIN_SSPERCENT)) | pin_flags;
-
-/*
-    ii->p.txtblk->pin_flags = (ii->p.txtblk->pin_flags & PIN_FIXED) | pin_flags;
-*/
-
     *tbptr = ii->p.txtblk;
     tbptr = &(ii->p.txtblk->next);
     }
@@ -303,33 +298,6 @@ for (ii = i; ii != i->partner; ii = ii->next)
 
     break;
     }
-
-
-#ifdef NEVER
-  /* This code has now been moved into font.c so that the sub/superscript info
-  is put into textblocks earlier, which enables index items to use it when
-  sorting, so that TEX (unsubscripted) and TEX (subscripted), for example, sort
-  differently. */
-
-  /* Handle subscripts and superscripts, but only to one level. */
-
-  else if (Ustrcmp(ii->name, "subscript") == 0)
-    pin_flags = (pin_flags & ~PIN_SSPERCENT) |
-                (subscript_down << SSPERCENT_SHIFT) |
-                PIN_SUBSCRIPT;
-  else if (Ustrcmp(ii->name, "superscript") == 0)
-    pin_flags = (pin_flags & ~PIN_SSPERCENT) |
-                (superscript_up << SSPERCENT_SHIFT) |
-                PIN_SUPERSCRIPT;
-  else if (Ustrcmp(ii->name, "/") == 0)
-    {
-    if (Ustrcmp(ii->partner->name, "subscript") == 0)
-      pin_flags &= ~PIN_SUBSCRIPT;
-    else if (Ustrcmp(ii->partner->name, "superscript") == 0)
-      pin_flags &= ~PIN_SUPERSCRIPT;
-    }
-#endif
-
   }
 
 /* If the paragraph consists just of a single &#x200b; character (a zero-width
@@ -1950,7 +1918,6 @@ tdatastr *td = NULL;
 int justify = J_LEFT;
 int colnumber = -1;
 int widest_line = 0;
-int bullet = -1;
 int nestindent = 0;
 int nestendent = 0;
 int extraliteralindent = 0;
@@ -2064,7 +2031,6 @@ for (i = item_list->next; i != NULL; i = i->next)
     nestendent += currlistendent[list_nest_depth++];
     currlistindent[list_nest_depth] = lptable[mainorfn + LP_ILISTPARA]->indent;
     currlistendent[list_nest_depth] = lptable[mainorfn + LP_ILISTPARA]->endent;
-    bullet = 0;
     continue;
     }
 
@@ -2215,27 +2181,6 @@ for (i = item_list->next; i != NULL; i = i->next)
 
   justify = (pg->justify != J_UNSET)? pg->justify : lp->justify;
 
-  /* At the start of an itemized list or a listitem with an overriding bullet
-  mark, we must ensure that an appropriate auxiliary font is set up if
-  necessary for the bullet character(s). Finding a character's width will get
-  all the necessary work done. We can't do it till now because we need to have
-  the paragraph's first textblock so we can get its vfont.
-
-  If bullet == 0, set up the default list of bullet characters. Otherwise,
-  assume it is a specified character value. */
-
-  if (bullet >= 0)
-    {
-    if (bullet > 0)
-      (void)font_charwidth(bullet, tb->vfont, NULL);
-    else
-      {
-      int *xp = bullets_default;
-      while (*xp != 0) (void)font_charwidth(*xp++, tb->vfont, NULL);
-      }
-    bullet = -1;
-    }
-
   /* If we are filling, we remove spaces at the start of the paragraph, and we
   also coalesce multiple spaces in the middle. This assumes that when there are
   font changes, the widths of spaces are the same in each font. */
